@@ -64,6 +64,12 @@ void MainWindow::setup()
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
     ui->tabWidget->blockSignals(true);
     cmd = new Cmd(this);
+
+    QFont font("monospace");
+    font.setStyleHint(QFont::Monospace);
+    ui->outputBox->setFont(font);
+
+    fp_ver = getVersion("flatpak");
     user = "--system ";
 
     if (system("arch | grep -q x86_64") == 0) {
@@ -197,7 +203,7 @@ void MainWindow::listSizeInstalledFP()
     QTreeWidgetItemIterator it(ui->treeFlatpak);
     QString total = "0 bytes";
     QStringList list, runtimes;
-    if (VersionNumber(getVersion("flatpak")) < VersionNumber("1.0.1")) { // older version doesn't display all apps and runtimes without specifying them
+    if (fp_ver < VersionNumber("1.0.1")) { // older version doesn't display all apps and runtimes without specifying them
         list = cmd->getOutput("su $(logname) -c \"flatpak -d list --app " + user + "|tr -s ' ' |cut -f1,5,6 -d' '\"").split("\n");
         runtimes = cmd->getOutput("su $(logname) -c \"flatpak -d list --runtime " + user + "|tr -s ' '|cut -f1,5,6 -d' '\"").split("\n");
         if (!runtimes.isEmpty()) {
@@ -214,11 +220,13 @@ void MainWindow::listSizeInstalledFP()
             }
             ++it;
         }
-    } else {
+    } else if (fp_ver < VersionNumber("1.2.4")) {
         list = cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f1,5\"").split("\n");
-        for (const QString &item : list) {
-            total = addSizes(total, item.section("\t", 1));
-        }
+    } else {
+        list = cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + "|tr -s ' '|cut -f2,11\"").split("\n");
+    }
+    for (const QString &item : list) {
+        total = addSizes(total, item.section("\t", 1));
     }
 
     ui->labelNumSize->setText(total);
@@ -615,13 +623,23 @@ void MainWindow::displayPopularApps() const
 
 
 // Display only the listed apps
-void MainWindow::displayFiltered(const QStringList &list) const
+void MainWindow::displayFiltered(const QStringList &list, bool raw) const
 {
     qDebug() << "+++" << __PRETTY_FUNCTION__ << "+++";
 
     QStringList new_list;
-    for (const QString &item : list) {
-        new_list << item.section("\t", 0, 0);
+    if (raw) { // raw format that needs to be edited
+        if (fp_ver < VersionNumber("1.2.4")) {
+            for (const QString &item : list) {
+                new_list << item.section("\t", 0, 0); // remove size
+            }
+        } else {
+            for (const QString &item : list) {
+                new_list << item.section("\t", 1, 1).section("/", 1); // remove version and size
+            }
+        }
+    } else {
+        new_list = list;
     }
 
     int total = 0;
@@ -775,11 +793,17 @@ void MainWindow::displayFlatpaks(bool force_update)
 
     QString short_name, full_name, arch, version, size;
     for (QString item : flatpaks) {
-        size = item.section("\t", 1);
-        item = item.section("\t", 0, 0); // strip size
-        full_name = item.section("/", 0, 0); // return first part of the name before slash
+        if (fp_ver < VersionNumber("1.2.4")) {
+            size = item.section("\t", 1, 1);
+            item = item.section("\t", 0, 0); // strip size
+            version = item.section("/", -1);
+        } else { // Buster and higher versions
+            size = item.section("\t", -1);
+            version = item.section("\t", 0, 0);
+            item = item.section("\t", 1, 1).section("/", 1);
+        }
+        full_name = item.section("/", 0, 0);
         short_name = full_name.section(".", -1);
-        version = item.section("/", -1);
         if (short_name == "Locale" || short_name == "Sources" || short_name == "Debug") { // skip Locale, Sources, Debug
             continue;
         }
@@ -1447,18 +1471,25 @@ QStringList MainWindow::listFlatpaks(const QString remote, const QString type)
 
     QStringList list;
     // need to specify arch for older version
-    QString arch = "";
-    if (VersionNumber(getVersion("flatpak")) < VersionNumber("1.0.1")) {
-        if (system("arch | grep -q x86_64") == 0) {
-            arch = "--arch=x86_64 ";
-        } else {
-            arch = "--arch=i386 ";
-        }
+    QString arch_fp;
+    if (fp_ver < VersionNumber("1.0.1")) {
+        arch_fp = (arch == "amd64") ? arch_fp = "--arch=x86_64 " : arch_fp = "--arch=i386 ";
         // list packages, strip first part remote/ or app/ no size for old flatpak
-        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch + type + "| cut -f1 | tr -s ' ' | cut -f1 -d' '|sed 's/^[^\\/]*\\///g' \"").split("\n");
-    } else {
+        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1 | tr -s ' ' | cut -f1 -d' '|sed 's/^[^\\/]*\\///g' \"").split("\n");
+    } else if (fp_ver < VersionNumber("1.2.4")) { // lower than Buster version
         // list size too
-        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch + type + "| cut -f1,3 |tr -s ' ' | sed 's/^[^\\/]*\\///g' \"").split("\n");
+        list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + type + "| cut -f1,3 |tr -s ' ' | sed 's/^[^\\/]*\\///g' \"").split("\n");
+    } else { // Buster version and above
+        // list version too
+        QString process_string; // unfortunatelly the resulting string structure is different depending on type option
+        if (type == "--app" || type.isEmpty()) {
+            process_string = "| cut -f3,6,9";
+            list = cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--app" + process_string + " \"").split("\n");
+        }
+        if (type == "--runtime" || type.isEmpty()) {
+            process_string = "| cut -f4,6,9";
+            list += cmd->getOutput("su $(logname) -c \"set -o pipefail; flatpak -d remote-ls " + user + remote + " " + arch_fp + "--runtime" + process_string + " \"").split("\n");
+        }
     }
 
     if (cmd->getExitCode(true) != 0) {
@@ -1466,19 +1497,17 @@ QStringList MainWindow::listFlatpaks(const QString remote, const QString type)
         return QStringList();
     }
 
-    // build cache lists
-    if (type == "--app") {
-        flatpaks_apps = list;
-    } else if (type == "--runtime") {
-        flatpaks_runtimes = list;
-    }
     return list;
 }
 
 // list installed flatpaks by type: apps, runtimes, or all (if no type is provided)
 QStringList MainWindow::listInstalledFlatpaks(const QString type) const
 {
-    return cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + type + "|cut -f1|cut -f1 -d' '\"").remove(" ").split("\n");
+    if (fp_ver < VersionNumber("1.2.4")) {
+        return cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + type + "|cut -f1|cut -f1 -d' '\"").remove(" ").split("\n");
+    } else {
+        return cmd->getOutput("su $(logname) -c \"flatpak -d list " + user + type + "|cut -f8\"").remove(" ").split("\n");
+    }
 }
 
 
@@ -1879,7 +1908,7 @@ void MainWindow::on_buttonUninstall_clicked()
 
         // new version of flatpak takes a "-y" confirmation
         QString conf = "-y ";
-        if (VersionNumber(getVersion("flatpak")) < VersionNumber("1.0.1")) {
+        if (fp_ver  < VersionNumber("1.0.1")) {
             conf = "";
         }
 
@@ -1896,6 +1925,7 @@ void MainWindow::on_buttonUninstall_clicked()
             listFlatpakRemotes();
             ui->comboRemote->setCurrentIndex(0);
             on_comboRemote_activated(ui->comboRemote->currentIndex());
+            ui->comboFilterFlatpak->setCurrentIndex(0);
             QMessageBox::information(this, tr("Done"), tr("Processing finished successfully."));
             ui->tabWidget->blockSignals(true);
             ui->tabWidget->setCurrentWidget(ui->tabFlatpak);
@@ -2102,14 +2132,14 @@ void MainWindow::filterChanged(const QString &arg1)
             displayFiltered(installed_apps_fp);
         } else if (arg1 == tr("All apps")) {
             if(flatpaks_apps.isEmpty()) {
-                listFlatpaks(ui->comboRemote->currentText(), "--app");
+                flatpaks_apps = listFlatpaks(ui->comboRemote->currentText(), "--app");
             }
-            displayFiltered(flatpaks_apps);
+            displayFiltered(flatpaks_apps, true);
         } else if (arg1 == tr("All runtimes")) {
             if(flatpaks_runtimes.isEmpty()) {
-                listFlatpaks(ui->comboRemote->currentText(), "--runtime");
+                flatpaks_runtimes = listFlatpaks(ui->comboRemote->currentText(), "--runtime");
             }
-            displayFiltered(flatpaks_runtimes);
+            displayFiltered(flatpaks_runtimes, true);
         } else if (arg1 == tr("All available")) {
             int total = 0;
             while (*it) {
